import React, { createContext, useState } from 'react';
import './Input.css';
import { MdCancel } from "react-icons/md";
import { Header } from '../Header/Header';
import { Checkbox } from './Checkbox';

export const MyTask = createContext();

export const Input = () => {
  const [task, setTask] = useState("");
  const [store, setStore] = useState([]);
  const [editIndex, setEditIndex] = useState(null);
  const [editedTask, setEditedTask] = useState("");

  const Change = (e) => {
    setTask(e.target.value);
  };

  const Add = () => {
    if (task.trim() === '') return;
    setStore([...store, task]);
    setTask("");
  };

  const Delete = (id) => {
    const updated = store.filter((_, index) => index !== id);
    setStore(updated);
  };

  const startEdit = (index) => {
    setEditIndex(index);
    setEditedTask(store[index]);
  };

  const saveEdit = (index) => {
    if (editedTask.trim() === '') return;
    const updated = [...store];
    updated[index] = editedTask;
    setStore(updated);
    setEditIndex(null);
  };

  return (
    <MyTask.Provider value={{ store, setStore }}>
      <>
        <Header />
        <ul>
          {store.map((item, index) => (
            <li key={index} className="todo">
              <div className="check">
                <Checkbox />
                {editIndex === index ? (
                  <span
                    contentEditable
                    suppressContentEditableWarning
                    autoFocus
                    onBlur={() => saveEdit(index)}
                    onInput={(e) => setEditedTask(e.currentTarget.textContent)}
                    onKeyDown={(e) => {
                      if (e.key === 'Enter') {
                        e.preventDefault();
                        e.currentTarget.blur();
                      }
                    }}
                    className="task"
                  >
                    {editedTask}
                  </span>
                ) : (
                  <span className="task" onClick={() => startEdit(index)}>{item}</span>
                )}
              </div>
              <button className="delete" onClick={() => Delete(index)}>
                <MdCancel />
              </button>
            </li>
          ))}
        </ul>

        <form onSubmit={(e) => e.preventDefault()}>
          <div className="merge">
            <input
              type="text"
              className="input"
              placeholder="Enter Items"
              value={task}
              onChange={Change}
            />
            <button onClick={Add} className="button">
              Submit
            </button>
          </div>
        </form>
      </>
    </MyTask.Provider>
  );
};
